ParticleSystem

Struct ParticleSystem 

pub struct ParticleSystem<Args: Clone, Data: Clone, Ret: Clone, F: GenFn<(i64, Args), Data, Ret>> {
    pub traces: Vec<Trace<(i64, Args), Data, Ret>>,
    /* private fields */
}
Basic particle filter for generative functions with a time parameter as the first input argument.

Fields

traces: Vec<Trace<(i64, Args), Data, Ret>>

Persistent traces contained within the system

Implementations

Source

impl<Args: Clone, Data: Clone, Ret: Clone, F: GenFn<(i64, Args), Data, Ret>> ParticleSystem<Args, Data, Ret, F>

pub fn new(model: F, num_particles: usize, rng: ThreadRng) -> Self

Construct a new particle filter under the model with num_particles particles.

pub fn init_step(&mut self, args: Args, constraints: Data)

Initialize the particle filter by generating self.num_particles traces from the model with (1, args).

pub fn step(self, constraints: Data) -> Self

Extend the current filter from t to t+1 with new constraints.

pub fn effective_sample_size(&self) -> f64

Calculate the effective sample size (ESS) with the current paticle weights.

pub fn resample(&mut self) -> f64

Perform multinomial resampling based on the normalized particle weights, and return the log total weight.

pub fn log_marginal_likelihood_estimate(&self) -> f64

Return the current log marginal likelihood estimate from the particles.